MicrodeContext

Trait MicrodeContext 

pub trait MicrodeContext: Send + Sync {
    // Required methods
    fn request_stop(&self, request: MicrodeStopRequest);
    fn panic(&self, error: Option<MicrodeError>) -> !;
}
Operations exposed by a application to its installed modules.

Required Methods

fn request_stop(&self, request: MicrodeStopRequest)

Requests an orderly stop and returns without waiting for lifecycle completion.

fn panic(&self, error: Option<MicrodeError>) -> !

Terminates execution immediately, bypassing the orderly shutdown lifecycle.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors